@@ -1,11 +1,8 @@
 from importlib import import_module
 from .config import load_config
-from django.conf import settings
 
 _loaders = {}
 
-ASSET_LOADER_CACHE = getattr(settings, "RUNTIME_ASSET_LOADER", False)
-
 
 def import_string(dotted_path):
     '''
@@ -22,7 +19,7 @@ def import_string(dotted_path):
 
 
 def get_loader(config_name, manifest_path=None):
-    if config_name not in _loaders or ASSET_LOADER_CACHE:
+    if config_name not in _loaders:
         config = load_config(config_name)
         loader_class = import_string(config['LOADER_CLASS'])
         _loaders[config_name] = loader_class(config, manifest_path)
@@ -52,6 +49,8 @@ def _page_bundle(extension, loader, page_name):
 
 def src_tags(bundle, asset_path, attrs):
     tags = []
+    if not bundle:
+        return tags
     for chunk in bundle:
         if chunk.endswith(('.js', '.js.gz')):
             tags.append((
@@ -64,6 +63,20 @@ def src_tags(bundle, asset_path, attrs):
     return tags
 
 
+def script_paths(bundle, asset_path):
+    tags = []
+    if not bundle:
+        return tags
+    for chunk in bundle:
+        if chunk.endswith(('.js', '.js.gz')):
+            file = "{0}{1}".format(asset_path, chunk)
+            tags.append(file)
+        elif chunk.endswith(('.css', '.css.gz')):
+            file = "{0}{1}".format(asset_path, chunk)
+            tags.append(file)
+    return tags
+
+
 def get_as_tags(extension=None, config='DEFAULT', attrs=''):
     loader = get_loader(config)
     bundle = _get_bundle(extension, loader)
@@ -76,3 +89,13 @@ def get_tags_per_page(extension=None, page_name='main', config='DEFAULT', manife
     bundle = _page_bundle(extension, loader, page_name)
     asset_path = loader.asset_path
     return src_tags(bundle, asset_path, attrs)
+
+
+def get_src_files(extension=None, page_name=None, config='DEFAULT'):
+    loader = get_loader(config)
+    if page_name:
+        bundle = _page_bundle(extension, loader, page_name)
+    else:
+        bundle = _get_bundle(extension, loader)
+    asset_path = loader.asset_path
+    return script_paths(bundle, asset_path)
